# !/bin/sh -xv
#
# module :
# define GEOMAG environnement
#
# usage :
# online usage
# $ . geomag_profile.sh -d directory
#
# in ${HOME}/.profile, add the following line
# . geomag_profile.sh -d directory
#
# examples :
# for fplod, on aedon.locean-ipsl.upmc.fr
# $ cd /usr/home/fplod/incas/geomag/geomag_ws
# $  . geomag_profile.sh -d /usr/home/fplod/incas/geomag/geomag_ws/
# for reee522 on rhodes.idris.fr
# $ cd ${HOME}/incas/geomag/geomag_ws/
# $ . geomag_profile.sh -d ${HOME}/incas/geomag/geomag_ws/
#
# original location
# geomag_profile.sh sur aedon.lodyc.jussieu.fr
#
# update :
# ++ option bavarde
# ++ machine dependant
# ++ besoin de posix
# ++ pas de MANPATH defini par dut sur zeus
# fplod 2007-03-13T16:12:41Z zeus.locean-ipsl.upmc.fr (Linux)
# add creation of $GEOMAG_ID and $GEOMAG_OD if they don't exist
# reee522 2006-11-23T11:41:41Z rhodes (IRIX64)
# pas de set -o posix sur rhodes (IRIX64)
# $Id$
# fplod 2006-03-22T10:13:38Z aedon.lodyc.jussieu.fr (Darwin)
# creation
#
#
command=geomag_profile.sh
#
usage=" Usage : ${command} -d directory"
#
while [ ! -z "${1}" ] # ++ pb bash
do
 case ${1} in
 -d) # directory choosen by user
  directory=${2}
  shift
 ;;
 *) # other choice
  echo "${usage}"
  # nb : no exit because this file should be launched by login process
 ;;
 esac
 shift # next flag
done

# check for ${directory}
if [ ! -d ${directory} ]
then
 echo " eee : ${directory} not found"
 # nb : no exit because this file should be launched by login process
fi
#
# check for permission on directory
if [ ! -x ${directory} ]
then
 echo " eee : ${directory} not reachable"
 # nb : no exit because this file should be launched by login process
fi
#
set -u
system=$(uname)
case ${system} in
IRIX64)
  echo " www : no specific posix checking"
;;
*)
  set -o posix
;;
esac
#
#
GEOMAG=${directory}
export GEOMAG
#
# add GEOMAG tools to PATH
# if not already done
echo ${PATH} | grep -q ${GEOMAG}
test_path=${?}
if [ ${test_path} -ne 0 ]
then
   PATH=${GEOMAG}/:${PATH}
   export PATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${GEOMAG}/ already in \${PATH}"
fi
#
# add GEOMAG manuals to MANPATH
# if not already done
echo ${MANPATH} | grep -q ${GEOMAG}
test_manpath=${?}
if [ ${test_manpath} -ne 0 ]
then
   MANPATH=${GEOMAG}/man/:${MANPATH}
   export MANPATH
else
   # option bavarde oui/non pas encore implante ++
   echo "${command} : iii : ${GEOMAG}/man/ already in \${MANPATH}"
fi
#
GEOMAG_LOG=/usr/temp/${LOGNAME}/log/
export GEOMAG_LOG
#
EDITOR=vi
export EDITOR
#
# io directories
GEOMAG_ID=${HOME}/geomag_d/
export GEOMAG_ID
if [ ! -d ${GEOMAG_ID} ] 
then
  mkdir -p ${GEOMAG_ID}
  echo "${command} : iii : creation of \${GEOMAG_ID}"
fi 
GEOMAG_OD=${HOME}/geomag_d/
export GEOMAG_OD
if [ ! -d ${GEOMAG_ID} ]
then
  mkdir -p ${GEOMAG_OD}
  echo "${command} : iii : creation of \${GEOMAG_OD}"
fi
#
# end
# nb : no exit because this file should be launched by login process
